| Title: | Czech Interest & Foreign Exchange Rates |
|---|---|
| Description: | Interface to interest and foreign exchange rates published by the Czech National Bank. |
| Authors: | Jindra Lacko [aut, cre] (ORCID: <https://orcid.org/0000-0002-0375-5156>) |
| Maintainer: | Jindra Lacko <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.5 |
| Built: | 2026-05-22 10:00:15 UTC |
| Source: | https://github.com/jla-data/czechrates |
A function returning data frame of FX rates as fixed by the central bank.
cnbfxrate(date = Sys.Date() - 1, specific_currency = "ALL")cnbfxrate(date = Sys.Date() - 1, specific_currency = "ALL")
date |
Date of publication as date, default is yesterday. |
specific_currency |
ISO Code of currency, default is ALL / complete list. |
a data frame - date_valid, currency ISO code, quoted amount, rate
cnbfxrate(as.Date("2002-08-12"), "EUR") # EUR/CZK rate for August 12th, 2002cnbfxrate(as.Date("2002-08-12"), "EUR") # EUR/CZK rate for August 12th, 2002
A function returning data frame of PRague InterBank OffeRed rates (PRIBOR).
pribor(date = Sys.Date() - 1, maturity = "1D")pribor(date = Sys.Date() - 1, maturity = "1D")
date |
Date of fixing as date, default is yesterday. |
maturity |
Maturity of loan as string, default is overnight ("1D"). |
The function expects date input, and returns data frame of two or more columns - date, and relevant PRIBOR rate (as determined by 'maturity' parameter).
PRIBOR rates are reported as fractions, i.e. not as percentages (i.e. 1% is reported as .01, not 1).
For dates when no PRIBOR was quoted (e.g. weekends, Bank Holidays, such as December 24th on any year, or August 13th, 2002 when no PRIBOR was quoted due to catastrophic floods) no result will be returned.
data frame - first column is date, second is relevant PRIBOR rate.
pribor(as.Date("2002-08-12"), "1D")pribor(as.Date("2002-08-12"), "1D")
A function returning data frame of two-week repo rate, as set by ČNB.
repo2w(date = Sys.Date() - 1)repo2w(date = Sys.Date() - 1)
date |
Date of fixing as date, default is yesterday. |
The function expects date input, and returns data frame of two columns - date, and relevant repo rate. It does not require maturity argument, as maturity is by definition 2W.
Repo rates are reported as fractions, i.e. not as percentages (i.e. 1% is reported as .01, not 1).
A single result will be reported for all dates higher than December 8th, 1995.
data frame - first column is date, second is relevant two-week repo rate (the primary CZK policy rate)
repo2w(as.Date("2002-08-12"))repo2w(as.Date("2002-08-12"))